@@ -10,13 +10,11 @@
 #'   for the table in a `Freq` column. The result is much like what you get
 #'   from [tidyr::pivot_longer()].
 #'
-#' @details Directly calls [tibble::as_tibble()] on a [base::table] object, which
-#'   does the same things as [base::as.data.frame.table()] but also gives the
-#'   returned object [tibble::tibble] class.
+#' @details Directly calls [tibble::as_tibble()] on a [base::table] object.
 #'
 #' @seealso [tibble::as_tibble.table()]
 #' @export
 tidy.table <- function(x, ...) {
-  .Deprecated()
+  .Deprecated(new = "tibble::as_tibble()")
   as_tibble(x)
 }
