@@ -20,7 +20,7 @@
 #'
 #' # load libraries for models and data
 #' library(betareg)
-#' 
+#'
 #' # load dats
 #' data("GasolineYield", package = "betareg")
 #'
@@ -28,7 +28,7 @@
 #' mod <- betareg(yield ~ batch + temp, data = GasolineYield)
 #'
 #' mod
-#' 
+#'
 #' # summarize model fit with tidiers
 #' tidy(mod)
 #' tidy(mod, conf.int = TRUE)
@@ -37,14 +37,14 @@
 #' augment(mod)
 #'
 #' glance(mod)
-#' 
+#'
 #' @export
 #' @seealso [tidy()], [betareg::betareg()]
 #' @family betareg tidiers
 #' @aliases betareg_tidiers
 tidy.betareg <- function(x, conf.int = FALSE, conf.level = .95, ...) {
   check_ellipses("exponentiate", "tidy", "betareg", ...)
-  
+
   ret <- map_as_tidy_tibble(
     purrr::map(coef(summary(x)), as.matrix),
     new_names = c("estimate", "std.error", "statistic", "p.value")
@@ -52,7 +52,7 @@ tidy.betareg <- function(x, conf.int = FALSE, conf.level = .95, ...) {
 
   if (conf.int) {
     ci <- broom_confint_terms(x, level = conf.level)
-    ret <- dplyr::left_join(ret, ci, by = "term")
+    ret <- dplyr::bind_cols(ret, ci[c("conf.low", "conf.high")])
   }
 
   as_tibble(ret)
