@@ -6,15 +6,16 @@ skip_if_not_installed("modeltests")
 library(modeltests)
 
 skip_if_not_installed("margins")
+library(margins)
 
 fit1 <- glm(am ~ cyl + hp + wt, data = mtcars, family = binomial)
-marg1 <- margins::margins(fit1)
+marg1 <- margins(fit1)
 
 fit2 <- lm(mpg ~ wt * cyl * disp, data = mtcars)
-marg2a <- margins::margins(fit2)
-marg2b <- margins::margins(fit2, variable = "wt")
-marg2c <- margins::margins(fit2, at = list(cyl = c(4, 6, 8)))
-marg2d <- margins::margins(fit2, variables = "wt", at = list(cyl = c(4, 6, 8), drat = c(3, 3.5, 4)))
+marg2a <- margins(fit2)
+marg2b <- margins(fit2, variable = "wt")
+marg2c <- margins(fit2, at = list(cyl = c(4, 6, 8)))
+marg2d <- margins(fit2, variables = "wt", at = list(cyl = c(4, 6, 8), drat = c(3, 3.5, 4)))
 
 test_that("margins tidier arguments", {
   check_arguments(tidy.margins)
