@@ -1,5 +1,10 @@
 context("mass-ridgelm")
 
+skip_on_cran()
+
+skip_if_not_installed("modeltests")
+library(modeltests)
+
 skip_if_not_installed("MASS")
 
 names(longley)[1] <- "y"
@@ -12,10 +17,9 @@ test_that("MASS::lm.ridge tidier arguments", {
 })
 
 test_that("tidy.ridgelm", {
-  
   td2 <- tidy(fit2)
   td3 <- tidy(fit3)
-  
+
   check_tidy_output(td2)
   check_tidy_output(td3)
 })
