@@ -84,7 +84,6 @@ test_that("tidy.power.htest", {
 
 
 test_that("augment.htest (chi squared test)", {
-
   # doesn't have a data argument
   check_arguments(augment.htest, strict = FALSE)
 
@@ -117,3 +116,15 @@ test_that("augment.htest (chi squared test)", {
     regexp = "Augment is only defined for chi squared hypothesis tests."
   )
 })
+
+test_that("tidy.htest does not return matrix columns", {
+  skip_if_not_installed("survey")
+  data(api, package = "survey")
+  dclus1 <- survey::svydesign(id = ~dnum, weights = ~pw, data = apiclus1, fpc = ~fpc)
+
+  expect_true(
+    survey::svychisq(~ sch.wide + stype, design = dclus1, statistic = "Wald") %>%
+      tidy() %>%
+      purrr::none(~ inherits(., "matrix"))
+  )
+})
