@@ -1,5 +1,10 @@
 context("survival-cch")
 
+skip_on_cran()
+
+skip_if_not_installed("modeltests")
+library(modeltests)
+
 skip_if_not_installed("survival")
 library(survival)
 
@@ -15,11 +20,11 @@ ccoh.data$age <- ccoh.data$age / 12
 fit <- cch(
   Surv(edrel, rel) ~ stage + histol + age,
   data = ccoh.data,
-  subcoh = ~ subcohort, id = ~ seqno, cohort.size = 4028
+  subcoh = ~subcohort, id = ~seqno, cohort.size = 4028
 )
 
 test_that("cch tidier arguments", {
-  check_arguments(tidy.cch)
+  check_arguments(tidy.cch, strict = FALSE)
   check_arguments(glance.cch)
 })
 
