@@ -1,10 +1,15 @@
 context("survival-survreg")
 
+skip_on_cran()
+
+skip_if_not_installed("modeltests")
+library(modeltests)
+
 skip_if_not_installed("survival")
 library(survival)
 
 sr <- survreg(Surv(futime, fustat) ~ ecog.ps + rx, ovarian,
-              dist = "exponential"
+  dist = "exponential"
 )
 
 test_that("survreg tidier arguments", {
@@ -13,12 +18,18 @@ test_that("survreg tidier arguments", {
   check_arguments(augment.survreg)
 })
 
-
 test_that("tidy.survreg", {
   td <- tidy(sr)
+  td2 <- tidy(sr, conf.int = TRUE)
+
   check_tidy_output(td)
-  check_dims(td, 3, 7)
+  check_tidy_output(td2)
+
+  check_dims(td, 3, 5)
+  check_dims(td2, 3, 7)
+
   expect_equal(td$term, c("(Intercept)", "ecog.ps", "rx"))
+  expect_equal(td2$term, c("(Intercept)", "ecog.ps", "rx"))
 })
 
 test_that("glance.survreg", {
@@ -27,12 +38,6 @@ test_that("glance.survreg", {
 })
 
 test_that("augment.survreg", {
-  
-  expect_error(
-    augment(sr),
-    regexp = "Must specify either `data` or `newdata` argument."
-  )
-  
   check_augment_function(
     aug = augment.survreg,
     model = sr,
@@ -40,3 +45,17 @@ test_that("augment.survreg", {
     newdata = ovarian
   )
 })
+
+test_that("tidy.survreg with robust std err", {
+  sr <- survreg(Surv(futime, fustat) ~ ecog.ps + rx, ovarian,
+    dist = "exponential", robust = TRUE
+  )
+  td <- tidy(sr)
+  td2 <- tidy(sr, conf.int = TRUE)
+
+  check_tidy_output(td)
+  check_tidy_output(td2)
+
+  check_dims(td, 3, 5)
+  check_dims(td2, 3, 7)
+})
